pub fn replace_all(
text: &str,
matches: &[Match],
template: &str,
) -> ReplaceResultExpand description
Perform replacement across all matches, returning the output string and segment metadata.
pub fn replace_all(
text: &str,
matches: &[Match],
template: &str,
) -> ReplaceResultPerform replacement across all matches, returning the output string and segment metadata.