pub fn parse_find_header(blob: &[u8]) -> (Option<FindHeader>, &[u8])Expand description
Split a Find response blob into its optional header and the remaining path lines.
pub fn parse_find_header(blob: &[u8]) -> (Option<FindHeader>, &[u8])Split a Find response blob into its optional header and the remaining path lines.