FilterApp

Struct FilterApp 

pub struct FilterApp {
    pub pattern_editor: Editor,
    pub options: FilterOptions,
    pub lines: Vec<String>,
    pub matched: Vec<usize>,
    pub selected: usize,
    pub scroll: usize,
    pub error: Option<String>,
    pub should_quit: bool,
    pub outcome: Outcome,
    /* private fields */
}

Fields

pattern_editor: Editoroptions: FilterOptionslines: Vec<String>matched: Vec<usize>

Indices of lines that currently match the pattern.

selected: usize

Selected index into matched for the cursor in the match list.

scroll: usize

Scroll offset (first visible index into matched).

error: Option<String>

Compilation error from the last recompute, if any.

should_quit: bool

Whether to quit the event loop on next tick.

outcome: Outcome

Outcome decided by the user: emit the filtered output, or discard.

Implementations

Source

impl FilterApp

pub fn new( lines: Vec<String>, initial_pattern: &str, options: FilterOptions, ) -> Self

pub fn pattern(&self) -> &str

pub fn recompute(&mut self)

pub fn select_next(&mut self)

pub fn select_prev(&mut self)

pub fn toggle_case_insensitive(&mut self)

pub fn toggle_invert(&mut self)